@@ -377,6 +377,11 @@ struct _NDR64_POINTER_FORMAT
 __midl_frag8_t;
 extern const __midl_frag8_t __midl_frag8;
 
+typedef 
+NDR64_FORMAT_CHAR
+__midl_frag7_t;
+extern const __midl_frag7_t __midl_frag7;
+
 typedef 
 struct 
 {
@@ -400,6 +405,11 @@ struct _NDR64_POINTER_FORMAT
 __midl_frag4_t;
 extern const __midl_frag4_t __midl_frag4;
 
+typedef 
+NDR64_FORMAT_CHAR
+__midl_frag3_t;
+extern const __midl_frag3_t __midl_frag3;
+
 typedef 
 struct 
 {
@@ -504,6 +514,9 @@ static const __midl_frag8_t __midl_frag8 =
     &__midl_frag9
 };
 
+static const __midl_frag7_t __midl_frag7 =
+0x2    /* FC64_INT8 */;
+
 static const __midl_frag6_t __midl_frag6 =
 { 
 /*  */
@@ -542,7 +555,7 @@ static const __midl_frag5_t __midl_frag5 =
     { 
     /* struct _NDR64_ARRAY_ELEMENT_INFO */
         (NDR64_UINT32) 1 /* 0x1 */,
-        &__midl_frag14
+        &__midl_frag7
     }
 };
 
@@ -555,6 +568,9 @@ static const __midl_frag4_t __midl_frag4 =
     &__midl_frag5
 };
 
+static const __midl_frag3_t __midl_frag3 =
+0x5    /* FC64_INT32 */;
+
 static const __midl_frag2_t __midl_frag2 =
 { 
 /* LeechRpc_ReservedSubmitCommand */
@@ -583,7 +599,7 @@ static const __midl_frag2_t __midl_frag2 =
     },
     { 
     /* cbIn */      /* parameter cbIn */
-        &__midl_frag9,
+        &__midl_frag3,
         { 
         /* cbIn */
             0,
